#
# spec file for package vhostmd
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define with_xen        0%{!?_without_xen:1}

# Xen is available only on x86_64
%ifnarch x86_64
%define with_xen        0
%endif

Name:           vhostmd
BuildRequires:  libtool
BuildRequires:  libvirt-devel
BuildRequires:  libxml2
BuildRequires:  libxml2-devel
BuildRequires:  pkg-config
%if %{with_xen}
BuildRequires:  xen-devel
%endif
Summary:        Virtual Host Metrics Daemon (vhostmd)
License:        LGPL-2.1+
Group:          System/Daemons
Version:        0.4      
Release:        23.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         coreutils, %insserv_prereq
Source0:        vhostmd-%{version}.tar.bz2
Patch0:         vhostmd-conf.patch
Patch1:         manpage.patch
Patch2:         value-newline.patch
Patch3:         libmetrics-link.patch
Patch4:         build-improvements.patch

%description 
vhostmd provides a "metrics communication channel" between a host and
its hosted virtual machines, allowing limited introspection of host
resource usage from within virtual machines



Authors:
--------
    Jim Fehlig <jfehlig@novell.com>
    Pat Campbell

%package -n    vm-dump-metrics
Summary:        Virtual Host Metrics Daemon (vhostmd)
Group:          System/Monitoring

%description -n vm-dump-metrics
vhostmd provides a "metrics communication channel" between a host and
its hosted virtual machines, allowing limited introspection of host
resource usage from within virtual machines



Authors:
--------
    Jim Fehlig <jfehlig@novell.com>
    Pat Campbell

%package -n    vm-dump-metrics-devel
Summary:        Virtual Host Metrics Daemon (vhostmd)
Group:          Development/Libraries/C and C++
Requires:       vm-dump-metrics = %{version}

%description -n vm-dump-metrics-devel
vhostmd provides a "metrics communication channel" between a host and
its hosted virtual machines, allowing limited introspection of host
resource usage from within virtual machines



Authors:
--------
    Jim Fehlig <jfehlig@novell.com>
    Pat Campbell

%prep
%setup
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1

%build
%if ! %{with_xen}
%define _disable_libxenstat --disable-libxenstat
%define _disable_xenctrl --disable-xenctrl
%endif

autoreconf -fi
%configure --without-xenstore \
     %{?_disable_libxenstat}  \
     %{?_disable_xenctrl}
make

%preun
# Start of pre-remove script
%{stop_on_removal vhostmd}
# exit 0
# End of pre-remove script

%postun
# Start post-remove script
%restart_on_update vhostmd
%{insserv_cleanup}

%install
# init scripts
make DESTDIR=$RPM_BUILD_ROOT install
ln -s /etc/init.d/vhostmd $RPM_BUILD_ROOT/usr/sbin/rcvhostmd

%post -n vm-dump-metrics-devel
# Start post-insall script
sbin/ldconfig

%postun -n vm-dump-metrics-devel
# Start post-remove script
sbin/ldconfig

%files
%defattr(-,root,root)
%dir /etc/vhostmd
%dir /usr/share/vhostmd
%dir /usr/share/vhostmd/scripts
%dir /usr/share/doc/vhostmd
/usr/sbin/vhostmd
/usr/sbin/rcvhostmd
/usr/share/vhostmd/scripts/pagerate.pl
%config(noreplace) /etc/vhostmd/vhostmd.conf
%config /etc/vhostmd/vhostmd.dtd
%config /etc/vhostmd/metric.dtd
/etc/init.d/vhostmd
/usr/share/doc/vhostmd/vhostmd.dtd
/usr/share/doc/vhostmd/metric.dtd
/usr/share/doc/vhostmd/vhostmd.xml
/usr/share/doc/vhostmd/mdisk.xml
/usr/share/doc/vhostmd/README
/usr/share/man/man8/vhostmd.8.gz

%files -n vm-dump-metrics
%defattr(-,root,root)
/usr/sbin/vm-dump-metrics
/usr/share/man/man1/vm-dump-metrics.1.gz

%files -n vm-dump-metrics-devel
%defattr(-,root,root)
%{_libdir}/libmetrics.a
%{_libdir}/libmetrics.la
%{_libdir}/libmetrics.so
%{_libdir}/libmetrics.so.0
%{_libdir}/libmetrics.so.0.0.0
%dir /usr/include/vhostmd
/usr/include/vhostmd/libmetrics.h

%changelog
* Wed Jan 14 2015 jfehlig@suse.com
- Build vhostmd for all architectures
* Mon Nov 10 2014 jfehlig@suse.com
- Improve build scripts
  Replace build-fix.patch with build-improvements.patch
* Mon Nov  3 2014 jfehlig@suse.com
- Fix Factory build
  build-fix.patch
* Fri Jun 13 2014 mlatimer@suse.com
- Further updates to vmhostd.xml
  - Support both xen and non-xen hypervisors (kvm)
  - Document reserved characters in 'action' field
  - Revert xen_version back to major/minor/extra to maintain compatability
    with xend
  - Minor syntax and legibility cleanup
  vhostmd-conf.patch
  bnc#872736
* Wed Jun 11 2014 mlatimer@suse.com
- Various updates to vmhostd.xml
  - Replace xm commands with xl commands
  - Add /sbin and /bin to <path>
  - Use xen_version for VirtualizationProductInfo
  vhostmd-conf.patch
* Mon Dec  9 2013 jfehlig@suse.com
- link libmetrics with libxml to fix Factory build
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Mar 30 2010 jfehlig@novell.com
- Fixed vm-dump-metrics man page
  bnc#592242
  manpage.patch
- Build vhostmd without xenstore support since it is not well
  tested on SuSE distributions.  Additionally, it can be confusing
  when used in context of KVM where xenstore does not exist.
- Strip 's' (seconds) from metrics that contain a time value
  vhostmd-conf.patch
- Remove stray newline from metric values to improve XML readability
  value-newline.patch
* Wed Dec  9 2009 jfehlig@novell.com
- Release of version 0.4
  - configure.ac: Fix C compiler detection to be compatible with
    automake
  - chdir ("/") when daemonizing self
* Fri Oct 30 2009 jfehlig@novell.com
- Release of version 0.3
  - change default disk location to /dev/shm/vhostmd0
  - open metrics disk with O_DIRECT
  - Fixes for '--with{,out}-xenstore' option
  - Allow gcc to check calls to vu_log* printf-like functions
  - Always connect to libvirt read-only
  - Add '-u user' command line option to drop root privs
  - Add '-c uri' command line option to specify libvirt connection
    URI
  - Add CONNECT substitution <action>s
  - vm-dump-metrics: On error, exit with status code 1
* Tue Sep 29 2009 aj@suse.de
- Fix devel package requires.
* Wed Sep 16 2009 dmueller@suse.de
- fix devel package requires
* Mon Jun 29 2009 jfehlig@novell.com
- Validate XML returned by 'action' for metric type 'xml'
- Do not convert metrics values internally in vhostmd.  Treat
  all metric values as strings and leave it to consumers to do
  any conversion.
* Fri Jun 26 2009 jfehlig@novell.com
- Allow larger buffer for 'xml' type
* Thu Jun 25 2009 jfehlig@novell.com
- Add metric type 'XML'
* Fri Jun 19 2009 jfehlig@novell.com
- vhostmd is currently only used with Xen so make it
  ExclusiveArch x86 and x86_64
* Mon Jun 15 2009 jfehlig@novell.com
- Truncate metrics disk on open
* Tue Jun  9 2009 jfehlig@novell.com
- Change COPYING from GPL3 to LGPL2.1
* Fri Jun  5 2009 jfehlig@novell.com
- Explicitly name subpackages with -n
* Thu Jun  4 2009 jfehlig@novell.com
- Version 0.2
  - Updated documentation
  - Added group metric type
  - Added perl script for generating {PageIn,PageFault}Rate
* Wed Jan  7 2009 plc@novell.com
- Initial creation
